/*******************************************************************************
 * Copyright (c) 2011 Google, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package com.something.layout;

import java.net.URL;

import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.Path;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 * 
 * @author lobas_av
 * @coverage ercp
 */
public class Activator extends AbstractUIPlugin {
	private static Activator m_plugin;

	// //////////////////////////////////////////////////////////////////////////
	//
	// Life cycle
	//
	// //////////////////////////////////////////////////////////////////////////
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		m_plugin = this;
	}

	@Override
	public void stop(BundleContext context) throws Exception {
		m_plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */
	public static Activator getDefault() {
		return m_plugin;
	}

	// //////////////////////////////////////////////////////////////////////////
	//
	// Files
	//
	// //////////////////////////////////////////////////////////////////////////
	/**
	 * Returns a URL to the specified entry in this bundle.
	 */
	public static URL getEntry(String name) {
		return m_plugin.getBundle().getEntry(name);
	}

	/**
	 * Returns a file URL to the specified entry in this bundle.
	 */
	public static URL getAbsoluteEntry(String name) throws Exception {
		return FileLocator.toFileURL(getEntry(name));
	}

	/**
	 * Returns absolute path for specified entry in this bundle.
	 */
	public static String getAbsolutePath(String name) throws Exception {
		URL url = getAbsoluteEntry(name);
		return new Path(url.getPath()).removeTrailingSeparator().toPortableString();
	}
}